pub struct SenderQueueBuilder<D>where
D: SenderQueueableConsensusProtocol,{ /* private fields */ }Expand description
A builder of a Honey Badger with a sender queue. It configures the parameters and creates a new
instance of SenderQueue.
Implementations
Sourceimpl<D> SenderQueueBuilder<D>where
D: SenderQueueableConsensusProtocol + Debug,
D::Message: Clone + SenderQueueableMessage<Epoch = D::Epoch>,
D::NodeId: NodeIdT,
D::Output: SenderQueueableOutput<D::NodeId, D::Epoch>,
impl<D> SenderQueueBuilder<D>where
D: SenderQueueableConsensusProtocol + Debug,
D::Message: Clone + SenderQueueableMessage<Epoch = D::Epoch>,
D::NodeId: NodeIdT,
D::Output: SenderQueueableOutput<D::NodeId, D::Epoch>,
Sourcepub fn new<I>(algo: D, peer_ids: I) -> Self
pub fn new<I>(algo: D, peer_ids: I) -> Self
Creates a new builder, with an empty outgoing queue and the specified known peers.
Sourcepub fn peer_epochs(self, peer_epochs: BTreeMap<D::NodeId, D::Epoch>) -> Self
pub fn peer_epochs(self, peer_epochs: BTreeMap<D::NodeId, D::Epoch>) -> Self
Sets the peer epochs.
Sourcepub fn build(
self,
our_id: D::NodeId,
) -> (SenderQueue<D>, CpStep<SenderQueue<D>>)
pub fn build( self, our_id: D::NodeId, ) -> (SenderQueue<D>, CpStep<SenderQueue<D>>)
Creates a new sender queue and returns the Step with the initial message.