SenderQueueableMessage

Trait SenderQueueableMessage 

pub trait SenderQueueableMessage {
    type Epoch: EpochT;

    // Required methods
    fn is_premature(&self, them: Self::Epoch, max_future_epochs: u64) -> bool;
    fn is_obsolete(&self, them: Self::Epoch) -> bool;
    fn first_epoch(&self) -> Self::Epoch;

    // Provided method
    fn is_accepted(&self, them: Self::Epoch, max_future_epochs: u64) -> bool { ... }
}
A message type that is suitable for use with a sender queue.

Required Associated Types

type Epoch: EpochT

The epoch type of the wrapped algorithm.

Required Methods

fn is_premature(&self, them: Self::Epoch, max_future_epochs: u64) -> bool

Whether the message needs to be deferred.

fn is_obsolete(&self, them: Self::Epoch) -> bool

Whether the epoch of the message is behind them.

fn first_epoch(&self) -> Self::Epoch

Returns the earliest epoch in which this message can be handled.

Provided Methods

fn is_accepted(&self, them: Self::Epoch, max_future_epochs: u64) -> bool

Whether the message is neither obsolete nor premature.

Implementors

Source

impl<N> SenderQueueableMessage for fedimint_hbbft::honey_badger::Message<N>

Source

impl<N: Ord> SenderQueueableMessage for fedimint_hbbft::dynamic_honey_badger::Message<N>