pub type Step<D> = CpStep<SenderQueue<D>>;Expand description
A SenderQueue step. The output corresponds to the wrapped algorithm.
Aliased Type
pub struct Step<D> {
pub output: Vec<<SenderQueue<D> as ConsensusProtocol>::Output>,
pub fault_log: FaultLog<<SenderQueue<D> as ConsensusProtocol>::NodeId, <SenderQueue<D> as ConsensusProtocol>::FaultKind>,
pub messages: Vec<TargetedMessage<<SenderQueue<D> as ConsensusProtocol>::Message, <SenderQueue<D> as ConsensusProtocol>::NodeId>>,
}Fields
output: Vec<<SenderQueue<D> as ConsensusProtocol>::Output>The algorithm’s output, after consensus has been reached. This is guaranteed to be the same in all nodes.
fault_log: FaultLog<<SenderQueue<D> as ConsensusProtocol>::NodeId, <SenderQueue<D> as ConsensusProtocol>::FaultKind>A list of nodes that are not following consensus, together with information about the detected misbehavior.
messages: Vec<TargetedMessage<<SenderQueue<D> as ConsensusProtocol>::Message, <SenderQueue<D> as ConsensusProtocol>::NodeId>>A list of messages that must be sent to other nodes. Each entry contains a message and a
Target.