pub struct Step<M, O, N, F: Error> {
pub output: Vec<O>,
pub fault_log: FaultLog<N, F>,
pub messages: Vec<TargetedMessage<M, N>>,
}Expand description
Single algorithm step outcome.
Each time input (typically in the form of user input or incoming network messages) is provided
to an instance of an algorithm, a Step is produced, potentially containing output values,
a fault log, and network messages.
Any Step must always be used by the client application; at the very least the resulting
messages must be queued.
Handling unused Steps
In the (rare) case of a Step not being of any interest at all, instead of discarding it
through let _ = ... or similar constructs, the implicit assumption should explicitly be
checked instead:
assert!(alg.propose(123).expect("Could not propose value").is_empty(),
"Algorithm will never output anything on first proposal");If an edge case occurs and outgoing messages are generated as a result, the assert! will
catch it, instead of potentially stalling the algorithm.
Fields
output: Vec<O>The algorithm’s output, after consensus has been reached. This is guaranteed to be the same in all nodes.
fault_log: FaultLog<N, F>A list of nodes that are not following consensus, together with information about the detected misbehavior.
messages: Vec<TargetedMessage<M, N>>A list of messages that must be sent to other nodes. Each entry contains a message and a
Target.
Implementations
Sourceimpl<M, O, N, F> Step<M, O, N, F>where
F: Error,
impl<M, O, N, F> Step<M, O, N, F>where
F: Error,
Sourcepub fn with_output<T: Into<Option<O>>>(self, output: T) -> Self
pub fn with_output<T: Into<Option<O>>>(self, output: T) -> Self
Returns the same step, with the given additional output.
Sourcepub fn map<M2, O2, F2, FO, FF, FM>(
self,
f_out: FO,
f_fail: FF,
f_msg: FM,
) -> Step<M2, O2, N, F2>
pub fn map<M2, O2, F2, FO, FF, FM>( self, f_out: FO, f_fail: FF, f_msg: FM, ) -> Step<M2, O2, N, F2>
Converts self into a step of another type, given conversion methods for output, faults,
and messages.
Sourcepub fn extend_with<M2, O2, F2, FF, FM>(
&mut self,
other: Step<M2, O2, N, F2>,
f_fail: FF,
f_msg: FM,
) -> Vec<O2>
pub fn extend_with<M2, O2, F2, FF, FM>( &mut self, other: Step<M2, O2, N, F2>, f_fail: FF, f_msg: FM, ) -> Vec<O2>
Extends self with others messages and fault logs, and returns other.output.
Sourceimpl<'i, M, O, N, F> Step<M, O, N, F>
impl<'i, M, O, N, F> Step<M, O, N, F>
Sourcepub fn defer_messages(
&mut self,
peer_epochs: &BTreeMap<N, M::Epoch>,
max_future_epochs: u64,
) -> Vec<(N, M)>
pub fn defer_messages( &mut self, peer_epochs: &BTreeMap<N, M::Epoch>, max_future_epochs: u64, ) -> Vec<(N, M)>
Removes and returns any messages that are not yet accepted by remote nodes according to the
mapping remote_epochs. This way the returned messages are postponed until later, and the
remaining messages can be sent to remote nodes without delay.