pub struct ThresholdSign<N> { /* private fields */ }Expand description
A threshold signing algorithm instance. On input, broadcasts our threshold signature share. Upon
receiving at least num_faulty + 1 shares, attempts to combine them into a signature. If that
signature is valid, the instance outputs it and terminates; otherwise the instance aborts.
Implementations
Sourceimpl<N: NodeIdT> ThresholdSign<N>
impl<N: NodeIdT> ThresholdSign<N>
Sourcepub fn new(netinfo: Arc<NetworkInfo<N>>) -> Self
pub fn new(netinfo: Arc<NetworkInfo<N>>) -> Self
Creates a new instance of ThresholdSign, with the goal to collaboratively sign doc.
Sourcepub fn new_with_document<M: AsRef<[u8]>>(
netinfo: Arc<NetworkInfo<N>>,
doc: M,
) -> Result<Self>
pub fn new_with_document<M: AsRef<[u8]>>( netinfo: Arc<NetworkInfo<N>>, doc: M, ) -> Result<Self>
Creates a new instance of ThresholdSign, including setting the document to sign.
Sourcepub fn set_document<M: AsRef<[u8]>>(&mut self, doc: M) -> Result<()>
pub fn set_document<M: AsRef<[u8]>>(&mut self, doc: M) -> Result<()>
Sets doc_hash. Signature shares can only be sent after this function is completed.
Sourcepub fn sign(&mut self) -> Result<Step<N>>
pub fn sign(&mut self) -> Result<Step<N>>
Sends our signature shares, and if we have collected enough, returns the full signature. Returns an error if the message to sign hasn’t been received yet.
Sourcepub fn handle_message(
&mut self,
sender_id: &N,
message: Message,
) -> Result<Step<N>>
pub fn handle_message( &mut self, sender_id: &N, message: Message, ) -> Result<Step<N>>
Handles a message with a signature share received from sender_id.
This must be called with every message we receive from another node.
If we have collected enough, returns the full signature.
Sourcepub fn netinfo(&self) -> &Arc<NetworkInfo<N>> ⓘ
pub fn netinfo(&self) -> &Arc<NetworkInfo<N>> ⓘ
Returns the information about the node IDs in the network, and the cryptographic keys.