pub trait SenderQueueableOutput<N, E>where
N: NodeIdT,{
// Required methods
fn participant_change(&self) -> Option<BTreeSet<N>>;
fn output_epoch(&self) -> E;
}Expand description
An output type compatible with the sender queue.
Required Methods
Sourcefn participant_change(&self) -> Option<BTreeSet<N>>
fn participant_change(&self) -> Option<BTreeSet<N>>
Returns the set of participants in the next epoch. New participants should be added to the set of peers for tracking their epochs. Old participants - ones that appear only among current participants - should be scheduled for removal from the set of peers in an orderly manner making sure that all messages those participants are entitled to are delivered to them.
The common case of no change in the set of participants is denoted by None.
Sourcefn output_epoch(&self) -> E
fn output_epoch(&self) -> E
The epoch in which the output was produced.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".