pub struct NetworkInfo<N> { /* private fields */ }Expand description
Common data shared between algorithms: the nodes’ IDs and key shares.
Implementations
Sourceimpl<N: NodeIdT> NetworkInfo<N>
impl<N: NodeIdT> NetworkInfo<N>
Sourcepub fn new<SKS: Into<Option<SecretKeyShare>>, V: Into<ValidatorSet<N>>>(
our_id: N,
secret_key_share: SKS,
public_key_set: PublicKeySet,
val_set: V,
) -> Self
pub fn new<SKS: Into<Option<SecretKeyShare>>, V: Into<ValidatorSet<N>>>( our_id: N, secret_key_share: SKS, public_key_set: PublicKeySet, val_set: V, ) -> Self
Creates a new NetworkInfo with the given ID and keys.
All nodes in the network must share the same public information. Validators’ IDs must be
keys in the public_keys map, and their secret key share must match their share in the
public_key_set.
Panics
Panics if public_keys is empty or the requirement above is not satisfied, i.e. if the
secret key doesn’t match the public key or is missing.
Sourcepub fn other_ids(&self) -> impl Iterator<Item = &N> + Clone
pub fn other_ids(&self) -> impl Iterator<Item = &N> + Clone
ID of all nodes in the network except this one.
Sourcepub fn num_faulty(&self) -> usize
pub fn num_faulty(&self) -> usize
The maximum number f of faulty, Byzantine nodes up to which Honey Badger is guaranteed to be correct.
Sourcepub fn num_correct(&self) -> usize
pub fn num_correct(&self) -> usize
The minimum number N - f of correct nodes with which Honey Badger is guaranteed to be correct.
Returns our secret key share for threshold cryptography, or None if not a validator.
Sourcepub fn public_key_set(&self) -> &PublicKeySet
pub fn public_key_set(&self) -> &PublicKeySet
Returns the public key set for threshold cryptography.
Returns the public key share if a node with that ID exists, otherwise None.
Returns a map of all node IDs to their public key shares.
Sourcepub fn node_index(&self, id: &N) -> Option<usize>
pub fn node_index(&self, id: &N) -> Option<usize>
The index of a node in a canonical numbering of all nodes. This is the index where the
node appears in all_ids.
Sourcepub fn is_validator(&self) -> bool
pub fn is_validator(&self) -> bool
Returns true if this node takes part in the consensus itself. If not, it is only an
observer.
Sourcepub fn is_node_validator(&self, id: &N) -> bool
pub fn is_node_validator(&self, id: &N) -> bool
Returns true if the given node takes part in the consensus itself. If not, it is only an
observer.
Sourcepub fn validator_set(&self) -> &Arc<ValidatorSet<N>>
pub fn validator_set(&self) -> &Arc<ValidatorSet<N>>
Returns the set of validator IDs.
Sourcepub fn generate_map<I, R>(
ids: I,
rng: &mut R,
) -> Result<BTreeMap<N, NetworkInfo<N>>, Error>where
I: IntoIterator<Item = N>,
R: Rng,
pub fn generate_map<I, R>(
ids: I,
rng: &mut R,
) -> Result<BTreeMap<N, NetworkInfo<N>>, Error>where
I: IntoIterator<Item = N>,
R: Rng,
Generates a map of matching NetworkInfos for testing.