pub struct ThresholdDecrypt<N> { /* private fields */ }Expand description
A Threshold Decrypt algorithm instance. If every node inputs the same data, encrypted to the network’s public key, every node will output the decrypted data.
Implementations
Sourceimpl<N: NodeIdT> ThresholdDecrypt<N>
impl<N: NodeIdT> ThresholdDecrypt<N>
Sourcepub fn new(netinfo: Arc<NetworkInfo<N>>) -> Self
pub fn new(netinfo: Arc<NetworkInfo<N>>) -> Self
Creates a new Threshold Decrypt instance.
Sourcepub fn new_with_ciphertext(
netinfo: Arc<NetworkInfo<N>>,
ct: Ciphertext,
) -> Result<Self>
pub fn new_with_ciphertext( netinfo: Arc<NetworkInfo<N>>, ct: Ciphertext, ) -> Result<Self>
Creates a new instance of ThresholdDecrypt, including setting the ciphertext to
decrypt.
Sourcepub fn set_ciphertext(&mut self, ct: Ciphertext) -> Result<()>
pub fn set_ciphertext(&mut self, ct: Ciphertext) -> Result<()>
Sets the ciphertext, sends the decryption share, and tries to decrypt it. This must be called exactly once, with the same ciphertext in all participating nodes. If we have enough shares, outputs the plaintext.
Sourcepub fn start_decryption(&mut self) -> Result<Step<N>>
pub fn start_decryption(&mut self) -> Result<Step<N>>
Sends our decryption shares to peers, and if we have collected enough, returns the decrypted message. Returns an error if the ciphertext hasn’t been received yet.
Sourcepub fn sender_ids(&self) -> impl Iterator<Item = &N>
pub fn sender_ids(&self) -> impl Iterator<Item = &N>
Returns an iterator over the IDs of all nodes who sent a share.